@@ -98,8 +98,8 @@
 
 #include <gio/gio.h>
 
-#define DEBUG_FLAG DEBUG_CONNECTOR
-#include "wocky-debug.h"
+#define WOCKY_DEBUG_FLAG WOCKY_DEBUG_CONNECTOR
+#include "wocky-debug-internal.h"
 
 #include "wocky-http-proxy.h"
 #include "wocky-sasl-auth.h"
@@ -109,7 +109,6 @@
 #include "wocky-namespaces.h"
 #include "wocky-xmpp-connection.h"
 #include "wocky-xmpp-error.h"
-#include "wocky-xmpp-error-enumtypes.h"
 #include "wocky-signals-marshal.h"
 #include "wocky-utils.h"
 
@@ -881,7 +880,7 @@ tcp_srv_connected (GObject *source,
 
       if ((host != NULL) && (*host != '\0'))
         {
-          DEBUG ("Falling back to HOST connection to %s", host);
+          DEBUG ("Falling back to HOST connection to %s port %u", host, port);
           connect_to_host_async (connector, host, port);
         }
       else
@@ -1183,8 +1182,7 @@ xmpp_features_cb (GObject *source,
   DEBUG ("received feature stanza from server");
   node = wocky_stanza_get_top_node (stanza);
 
-  if (wocky_strdiff (node->name, "features") ||
-      wocky_strdiff (wocky_node_get_ns (node), WOCKY_XMPP_NS_STREAM))
+  if (!wocky_node_matches (node, "features", WOCKY_XMPP_NS_STREAM))
     {
       char *msg = state_message (priv, "Malformed or missing feature stanza");
       abort_connect_code (data, WOCKY_CONNECTOR_ERROR_BAD_FEATURES, msg);
