@@ -27,10 +27,9 @@
 #include "wocky-signals-marshal.h"
 #include "wocky-namespaces.h"
 #include "wocky-utils.h"
-#include "wocky-xmpp-error-enumtypes.h"
 
-#define DEBUG_FLAG DEBUG_AUTH
-#include "wocky-debug.h"
+#define WOCKY_DEBUG_FLAG WOCKY_DEBUG_AUTH
+#include "wocky-debug-internal.h"
 
 G_DEFINE_TYPE(WockyJabberAuth, wocky_jabber_auth, G_TYPE_OBJECT)
 
@@ -647,6 +646,11 @@ wocky_jabber_auth_authenticate_async (WockyJabberAuth *self,
       NULL, NULL,
       '@', "id", id,
       '(', "query", ':', WOCKY_JABBER_NS_AUTH,
+      /* This is a workaround for
+       * <https://bugs.freedesktop.org/show_bug.cgi?id=24013>: while
+       * <http://xmpp.org/extensions/xep-0078.html#usecases> doesn't require
+       * us to include a username, it seems to be required by jabberd 1.4.
+       */
       '(', "username",
       '$', priv->username,
       ')',
