@@ -23,8 +23,16 @@
 #include <stdlib.h>
 #include <string.h>
 
+#ifdef G_OS_WIN32
+#include <windows.h>
+#include <ws2tcpip.h>
+#include <stdint.h>
+typedef uint32_t u_int32_t;
+typedef uint16_t u_int16_t;
+#else
 #include <sys/socket.h>
 #include <netinet/in.h>
+#endif
 
 #include "wocky-ll-connection-factory.h"
 #include "wocky-contact-factory.h"
@@ -34,8 +42,8 @@
 #include "wocky-ll-connector.h"
 #include "wocky-loopback-stream.h"
 
-#define DEBUG_FLAG DEBUG_PORTER
-#include "wocky-debug.h"
+#define WOCKY_DEBUG_FLAG WOCKY_DEBUG_PORTER
+#include "wocky-debug-internal.h"
 
 static void wocky_porter_iface_init (gpointer g_iface,
     gpointer iface_data);
@@ -192,6 +200,10 @@ static void porter_closing_cb (WockyPorter *porter, PorterData *data);
 static void porter_remote_closed_cb (WockyPorter *porter, PorterData *data);
 static void porter_remote_error_cb (WockyPorter *porter, GQuark domain,
     gint code, const gchar *msg, PorterData *data);
+static void porter_sending_cb (
+    WockyC2SPorter *child_porter,
+    WockyStanza *stanza,
+    PorterData *data);
 
 static void
 disconnect_porter_signal_handlers (WockyPorter *porter,
@@ -203,6 +215,8 @@ disconnect_porter_signal_handlers (WockyPorter *porter,
       porter_closing_cb, data);
   g_signal_handlers_disconnect_by_func (porter,
       porter_remote_error_cb, data);
+  g_signal_handlers_disconnect_by_func (porter,
+      porter_sending_cb, data);
 }
 
 static void
@@ -242,6 +256,15 @@ porter_remote_error_cb (WockyPorter *porter,
   porter_closing_cb (porter, data);
 }
 
+static void
+porter_sending_cb (
+    WockyC2SPorter *child_porter,
+    WockyStanza *stanza,
+    PorterData *data)
+{
+  g_signal_emit_by_name (data->self, "sending", stanza);
+}
+
 static void
 maybe_start_timeout (PorterData *data)
 {
@@ -311,6 +334,8 @@ create_porter (WockyMetaPorter *self,
       G_CALLBACK (porter_remote_closed_cb), data);
   g_signal_connect (data->porter, "remote-error",
       G_CALLBACK (porter_remote_error_cb), data);
+  g_signal_connect (data->porter, "sending",
+      G_CALLBACK (porter_sending_cb), data);
 
   register_porter_handlers (self, data->porter, contact);
   wocky_porter_start (data->porter);
@@ -605,10 +630,11 @@ free_handler (gpointer data)
           stanza_handler_porter_disposed_cb, handler);
     }
 
-  g_hash_table_destroy (handler->porters);
+  g_hash_table_unref (handler->porters);
   if (handler->contact != NULL)
     g_object_unref (handler->contact);
-  g_object_unref (handler->stanza);
+  if (handler->stanza != NULL)
+    g_object_unref (handler->stanza);
   g_slice_free (StanzaHandler, handler);
 }
 
@@ -738,8 +764,8 @@ wocky_meta_porter_dispose (GObject *object)
   g_socket_service_stop (priv->listener);
   g_object_unref (priv->listener);
 
-  g_hash_table_destroy (priv->porters);
-  g_hash_table_destroy (priv->handlers);
+  g_hash_table_unref (priv->porters);
+  g_hash_table_unref (priv->handlers);
 
   if (G_OBJECT_CLASS (wocky_meta_porter_parent_class)->dispose)
     G_OBJECT_CLASS (wocky_meta_porter_parent_class)->dispose (object);
@@ -1192,25 +1218,13 @@ register_porter_handler (StanzaHandler *handler,
 
   g_assert (g_hash_table_lookup (handler->porters, porter) == NULL);
 
-  if (handler->contact != NULL)
-    {
-      gchar *jid = wocky_contact_dup_jid (handler->contact);
-
-      id = wocky_porter_register_handler_from_by_stanza (porter,
-          handler->type, handler->sub_type, jid,
-          handler->priority, porter_handler_cb, handler,
-          handler->stanza);
-
-      g_free (jid);
-    }
-  else
-    {
-      id = wocky_porter_register_handler_from_anyone_by_stanza (porter,
-          handler->type, handler->sub_type,
-          handler->priority, porter_handler_cb, handler,
-          handler->stanza);
-    }
-
+  /* If handler->contact is not NULL, we know that this c2s porter is a
+   * connection to them, so we still don't need to tell it to match the sender.
+   */
+  id = wocky_porter_register_handler_from_anyone_by_stanza (porter,
+      handler->type, handler->sub_type,
+      handler->priority, porter_handler_cb, handler,
+      handler->stanza);
   g_hash_table_insert (handler->porters, porter, GUINT_TO_POINTER (id));
 
   g_object_weak_ref (G_OBJECT (porter),
@@ -1261,7 +1275,9 @@ stanza_handler_new (WockyMetaPorter *self,
   out->priority = priority;
   out->callback = callback;
   out->user_data = user_data;
-  out->stanza = g_object_ref (stanza);
+
+  if (stanza != NULL)
+    out->stanza = g_object_ref (stanza);
 
   return out;
 }
