@@ -41,8 +41,8 @@
 
 #include "wocky-stanza.h"
 
-#define DEBUG_FLAG DEBUG_XMPP_READER
-#include "wocky-debug.h"
+#define WOCKY_DEBUG_FLAG WOCKY_DEBUG_XMPP_READER
+#include "wocky-debug-internal.h"
 
 /* properties */
 enum {
@@ -439,9 +439,7 @@ handle_stream_open (
        */
       const gchar *attr_name = (const gchar *) attributes[i];
       const gchar *attr_prefix = (const gchar *) attributes[i+1];
-#ifdef ENABLE_DEBUG
       const gchar *attr_uri = (const gchar *) attributes[i+2];
-#endif
       gsize value_len = attributes[i+4] - attributes[i+3];
       gchar *attr_value = g_strndup (
           (const gchar *) attributes[i+3], value_len);
@@ -688,7 +686,7 @@ wocky_xmpp_reader_push (WockyXmppReader *reader, const guint8 *data,
   g_return_if_fail (priv->state < WOCKY_XMPP_READER_STATE_CLOSED);
 
 #ifdef ENABLE_DEBUG
-  wocky_debug (DEBUG_NET, "Parsing chunk: %.*s", (int)length, data);
+  wocky_debug (WOCKY_DEBUG_NET, "Parsing chunk: %.*s", (int)length, data);
 #endif
 
   parser = priv->parser;
