@@ -22,7 +22,7 @@
 
 #include <glib-object.h>
 
-#include <wocky/wocky-stanza.h>
+#include <wocky/wocky.h>
 
 G_BEGIN_DECLS
 
