@@ -32,7 +32,7 @@
 #include "gibber-r-multicast-packet.h"
 #include "gibber-r-multicast-sender.h"
 
-#include "signals-marshal.h"
+#include "gibber-signals-marshal.h"
 
 #define SESSION_TIMEOUT_MIN 1500
 #define SESSION_TIMEOUT_MAX 3000
@@ -250,14 +250,12 @@ gibber_r_multicast_causal_transport_class_init (
 
   param_spec = g_param_spec_object ("transport", "transport",
       "The underlying Transport", GIBBER_TYPE_TRANSPORT,
-      G_PARAM_CONSTRUCT_ONLY | G_PARAM_READWRITE | G_PARAM_STATIC_NAME |
-      G_PARAM_STATIC_BLURB);
+      G_PARAM_CONSTRUCT_ONLY | G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
   g_object_class_install_property (object_class, PROP_TRANSPORT, param_spec);
 
   param_spec = g_param_spec_string ("name", "name",
       "The name to use on the protocol", NULL,
-      G_PARAM_CONSTRUCT_ONLY | G_PARAM_READWRITE | G_PARAM_STATIC_NAME |
-      G_PARAM_STATIC_BLURB);
+      G_PARAM_CONSTRUCT_ONLY | G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS);
   g_object_class_install_property (object_class, PROP_NAME, param_spec);
 
   transport_class->send = gibber_r_multicast_causal_transport_do_send;
@@ -347,7 +345,7 @@ sendout_packet (GibberRMulticastCausalTransport *transport,
 static gchar *
 g_array_uint32_to_str (GArray *array)
 {
-  int i;
+  guint i;
   GString *str;
 
   if (array == NULL || array->len == 0) {
@@ -689,7 +687,7 @@ handle_session_message (GibberRMulticastCausalTransport *self,
 {
   GibberRMulticastCausalTransportPrivate *priv =
       GIBBER_R_MULTICAST_CAUSAL_TRANSPORT_GET_PRIVATE (self);
-  int i;
+  guint i;
   gboolean outdated = FALSE;
 
   g_assert (packet->type == PACKET_TYPE_SESSION);
@@ -736,7 +734,7 @@ handle_packet_depends (GibberRMulticastCausalTransport *self,
 {
   GibberRMulticastCausalTransportPrivate *priv =
       GIBBER_R_MULTICAST_CAUSAL_TRANSPORT_GET_PRIVATE (self);
-  int i;
+  guint i;
 
   g_assert (GIBBER_R_MULTICAST_PACKET_IS_RELIABLE_PACKET (packet));
 
