@@ -267,9 +267,7 @@ gibber_r_multicast_transport_class_init (
      "transport", "The underlying Transport",
       GIBBER_TYPE_TRANSPORT,
       G_PARAM_CONSTRUCT_ONLY |
-      G_PARAM_READWRITE      |
-      G_PARAM_STATIC_NAME    |
-      G_PARAM_STATIC_BLURB);
+      G_PARAM_READWRITE      | G_PARAM_STATIC_STRINGS);
 
   g_object_class_install_property (object_class, PROP_TRANSPORT,
                                   param_spec);
@@ -301,13 +299,13 @@ gibber_r_multicast_transport_flush_state (GibberRMulticastTransport *self)
 
   if (priv->send_join != NULL)
     {
-      g_array_free (priv->send_join, TRUE);
+      g_array_unref (priv->send_join);
       priv->send_join = NULL;
     }
 
   if (priv->send_join_failures != NULL)
     {
-      g_array_free (priv->send_join_failures, TRUE);
+      g_array_unref (priv->send_join_failures);
       priv->send_join_failures = NULL;
     }
 
@@ -353,10 +351,10 @@ gibber_r_multicast_transport_finalize (GObject *object)
      GibberRMulticastTransportPrivate *priv =
         GIBBER_R_MULTICAST_TRANSPORT_GET_PRIVATE (self);
 
-  g_hash_table_destroy (priv->members);
+  g_hash_table_unref (priv->members);
   if (priv->pending_failures != NULL)
     {
-      g_array_free (priv->pending_failures, TRUE);
+      g_array_unref (priv->pending_failures);
       priv->pending_failures = NULL;
     }
 
@@ -399,7 +397,7 @@ received_data (GibberTransport *transport, GibberBuffer *buffer,
 {
   GibberRMulticastTransport *self = GIBBER_R_MULTICAST_TRANSPORT (user_data);
   GibberRMulticastCausalBuffer *cbuffer =
-    (GibberRMulticastCausalBuffer *)buffer;
+    (GibberRMulticastCausalBuffer *) buffer;
   MemberState state;
 
   state = member_get_state (self, cbuffer->sender_id);
@@ -445,11 +443,11 @@ new_member (GibberRMulticastTransport *self, guint32 id)
 static void
 free_member_info (gpointer data)
 {
-  MemberInfo *info = (MemberInfo *)data;
+  MemberInfo *info = (MemberInfo *) data;
 
   if (info->fail_timeout != 0)
     g_source_remove (info->fail_timeout);
-  g_array_free (info->failures, TRUE);
+  g_array_unref (info->failures);
   g_slice_free (MemberInfo, info);
 }
 
@@ -538,7 +536,7 @@ member_list_to_str (GibberRMulticastTransport *self) {
 
 static void
 add_to_join (gpointer key, gpointer value, gpointer user_data) {
-  MemberInfo *info = (MemberInfo *)value;
+  MemberInfo *info = (MemberInfo *) value;
   GibberRMulticastTransport *self = GIBBER_R_MULTICAST_TRANSPORT (user_data);
   GibberRMulticastTransportPrivate *priv =
     GIBBER_R_MULTICAST_TRANSPORT_GET_PRIVATE (self);
@@ -652,8 +650,8 @@ setup_joining_phase (GibberRMulticastTransport *self)
   else
     {
       g_assert (priv->state == STATE_JOINING);
-      g_array_free (priv->send_join, TRUE);
-      g_array_free (priv->send_join_failures, TRUE);
+      g_array_unref (priv->send_join);
+      g_array_unref (priv->send_join_failures);
 
       priv->send_join = g_array_new (FALSE, FALSE, sizeof (guint32));
       priv->send_join_failures = g_array_new (FALSE, FALSE, sizeof (guint32));
@@ -698,7 +696,7 @@ start_joining_phase (GibberRMulticastTransport *self)
   GibberRMulticastTransportPrivate *priv =
     GIBBER_R_MULTICAST_TRANSPORT_GET_PRIVATE (self);
   GibberRMulticastSender *sender;
-  int i;
+  guint i;
 
   setup_joining_phase (self);
 
@@ -714,11 +712,11 @@ start_joining_phase (GibberRMulticastTransport *self)
    * failure packet */
   for (i = 0; i < priv->pending_failures->len; i++)
     {
-      GibberRMulticastSender *sender;
-      sender = gibber_r_multicast_causal_transport_get_sender (priv->transport,
+      GibberRMulticastSender *sender_;
+      sender_ = gibber_r_multicast_causal_transport_get_sender (priv->transport,
         g_array_index (priv->pending_failures, guint32, i));
 
-      gibber_r_multicast_sender_set_failed (sender);
+      gibber_r_multicast_sender_set_failed (sender_);
     }
 
   if (priv->pending_failures->len > 0)
@@ -791,7 +789,7 @@ guint32_array_remove (GArray *array, guint32 id)
 static void
 add_to_senders (gpointer key, gpointer value, gpointer user_data) {
   struct HTData *data = (struct HTData *)user_data;
-  MemberInfo *info = (MemberInfo *)value;
+  MemberInfo *info = (MemberInfo *) value;
 
   if (info->state == MEMBER_STATE_UNKNOWN) {
     info->state = MEMBER_STATE_ATTEMPT_JOIN_STARTED;
@@ -849,7 +847,7 @@ do_send_attempt_join (gpointer user_data) {
           data.senders, priv->repeating_join);
     priv->send_empty = FALSE;
   }
-  g_array_free (data.senders, TRUE);
+  g_array_unref (data.senders);
 
   return FALSE;
 }
@@ -968,7 +966,7 @@ received_foreign_packet_cb (GibberRMulticastCausalTransport *ctransport,
       /* Either the sender wants a start position from us or has replied to one
        * or our AJ messages.. Or it's some completely unrelated packet and we
        * can handle it just like any other reliable packet */
-      int i;
+      guint i;
       gboolean self_in_senders = FALSE;
 
       for (i = 0; i < packet->data.attempt_join.senders->len; i++) {
@@ -1095,8 +1093,8 @@ static gboolean
 find_unfailed_member (gpointer key, gpointer value, gpointer user_data)
 {
   guint i;
-  guint32 *id = (guint32 *)user_data;
-  MemberInfo *info = (MemberInfo *)value;
+  guint32 *id = (guint32 *) user_data;
+  MemberInfo *info = (MemberInfo *) value;
 
   if (info->state < MEMBER_STATE_ATTEMPT_JOIN_DONE ||
       info->state > MEMBER_STATE_MEMBER)
@@ -1116,8 +1114,8 @@ find_unfailed_member (gpointer key, gpointer value, gpointer user_data)
 static void
 remove_failure (gpointer key, gpointer value, gpointer user_data)
 {
-  guint32 *id = (guint32 *)user_data;
-  MemberInfo *info = (MemberInfo *)value;
+  guint32 *id = (guint32 *) user_data;
+  MemberInfo *info = (MemberInfo *) value;
 
   guint32_array_remove (info->failures, *id);
 }
@@ -1125,8 +1123,8 @@ remove_failure (gpointer key, gpointer value, gpointer user_data)
 static void
 collect_failed_members (gpointer key, gpointer value, gpointer user_data)
 {
-  MemberInfo *info = (MemberInfo *)value;
-  GArray *array = (GArray *)user_data;
+  MemberInfo *info = (MemberInfo *) value;
+  GArray *array = (GArray *) user_data;
 
   if (info->state >= MEMBER_STATE_FAILING &&
       info->state < MEMBER_STATE_INSTANT_FAILURE)
@@ -1150,7 +1148,7 @@ recheck_failures (GibberRMulticastTransport *self)
          g_array_index (array, guint32, i));
     }
 
-  g_array_free (array, TRUE);
+  g_array_unref (array);
 }
 
 static void
@@ -1181,7 +1179,7 @@ check_failure_completion (GibberRMulticastTransport *self, guint32 id)
           id);
       g_array_append_val (lost, sender->name);
       g_signal_emit (self, signals[LOST_SENDERS], 0, lost);
-      g_array_free (lost, TRUE);
+      g_array_unref (lost);
     }
 
   gibber_r_multicast_causal_transport_remove_sender (priv->transport, id);
@@ -1209,7 +1207,7 @@ check_failure_completion (GibberRMulticastTransport *self, guint32 id)
 static gboolean
 fail_member_timeout_cb (gpointer user_data)
 {
-  MemberInfo *info = (MemberInfo *)user_data;
+  MemberInfo *info = (MemberInfo *) user_data;
   GibberRMulticastTransport *self = info->transport;
   GibberRMulticastTransportPrivate *priv =
       GIBBER_R_MULTICAST_TRANSPORT_GET_PRIVATE(self);
@@ -1445,12 +1443,12 @@ check_join_agreement (GibberRMulticastTransport *self)
       switch (info->state)
         {
           case MEMBER_STATE_MEMBER_FAILING: {
-            GibberRMulticastSender *sender =
+            GibberRMulticastSender *sender_ =
               gibber_r_multicast_causal_transport_get_sender (priv->transport,
                 info->id);
             if (info->state == MEMBER_STATE_MEMBER_FAILING)
               {
-                gchar *name = g_strdup (sender->name);
+                gchar *name = g_strdup (sender_->name);
                 g_array_append_val (lost, name);
               }
           }
@@ -1479,17 +1477,17 @@ check_join_agreement (GibberRMulticastTransport *self)
       if (info->state != MEMBER_STATE_MEMBER &&
             info->state < MEMBER_STATE_FAILING)
         {
-          GibberRMulticastSender *sender;
+          GibberRMulticastSender *sender_;
 
-          sender = gibber_r_multicast_causal_transport_get_sender (
+          sender_ = gibber_r_multicast_causal_transport_get_sender (
               priv->transport, info->id);
 
-          DEBUG ("New member: %s (%x)", sender->name, info->id);
+          DEBUG ("New member: %s (%x)", sender_->name, info->id);
 
           info->state = MEMBER_STATE_MEMBER;
-          gibber_r_multicast_sender_set_data_start (sender,
+          gibber_r_multicast_sender_set_data_start (sender_,
               info->join_packet_id);
-          g_array_append_val (new, sender->name);
+          g_array_append_val (new, sender_->name);
         }
 
       if (info->state >= MEMBER_STATE_FAILING)
@@ -1508,12 +1506,12 @@ check_join_agreement (GibberRMulticastTransport *self)
     g_free (g_array_index (lost, gchar *, i));
   }
 
-  g_array_free (lost, TRUE);
-  g_array_free (new, TRUE);
+  g_array_unref (lost);
+  g_array_unref (new);
 
-  g_array_free (priv->send_join, TRUE);
+  g_array_unref (priv->send_join);
   priv->send_join = NULL;
-  g_array_free (priv->send_join_failures, TRUE);
+  g_array_unref (priv->send_join_failures);
   priv->send_join_failures = NULL;
   priv->state = STATE_NORMAL;
 
