@@ -35,11 +35,10 @@ GDebugKey keys[] = {
   { "tubes",          DEBUG_TUBES },
   { "xmpp-connection-manager",  DEBUG_XCM },
   { "si-bytestream-manager",    DEBUG_SI_BYTESTREAM_MGR },
-  { "discovery",      DEBUG_DISCO },
+  { "discovery",      DEBUG_DISCOVERY },
   { "olpc-activity",      DEBUG_OLPC_ACTIVITY },
   { "ft",             DEBUG_FT },
   { "plugin",         DEBUG_PLUGIN },
-  { "all",            ~0 },
   { 0, },
 };
 
@@ -101,7 +100,7 @@ debug_free (void)
   if (flag_to_keys == NULL)
     return;
 
-  g_hash_table_destroy (flag_to_keys);
+  g_hash_table_unref (flag_to_keys);
   flag_to_keys = NULL;
 }
 
