@@ -6,7 +6,7 @@
 
 #include <glib.h>
 
-#include <wocky/wocky-stanza.h>
+#include <wocky/wocky.h>
 
 #ifdef ENABLE_DEBUG
 
