@@ -24,7 +24,7 @@
 #include <stdlib.h>
 #include <string.h>
 
-#include <wocky/wocky-namespaces.h>
+#include <wocky/wocky.h>
 
 #include <gibber/gibber-file-transfer.h>
 
@@ -265,6 +265,8 @@ salut_ft_manager_channel_created (SalutFtManager *self,
   SalutFtManagerPrivate *priv = SALUT_FT_MANAGER_GET_PRIVATE (self);
   GSList *requests = NULL;
 
+  tp_base_channel_register (TP_BASE_CHANNEL (chan));
+
   g_signal_connect (chan, "closed", G_CALLBACK (file_channel_closed_cb), self);
 
   priv->channels = g_list_append (priv->channels, chan);
@@ -534,7 +536,7 @@ salut_ft_manager_type_foreach_channel_class (GType type,
   func (type, table, file_transfer_channel_allowed_properties_with_both_metadata_props,
       user_data);
 
-  g_hash_table_destroy (table);
+  g_hash_table_unref (table);
 }
 
 static void
@@ -633,7 +635,7 @@ add_file_transfer_channel_class (GPtrArray *arr,
       1, allowed_properties,
       G_MAXUINT);
 
-  g_hash_table_destroy (fixed_properties);
+  g_hash_table_unref (fixed_properties);
 
   g_ptr_array_add (arr, g_value_get_boxed (&monster));
 }
