@@ -21,13 +21,16 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
+
+#ifdef G_OS_UNIX
 #include <arpa/inet.h>
+#endif
 
 #include "muc-manager.h"
 
+#include <wocky/wocky.h>
+
 #include <gibber/gibber-muc-connection.h>
-#include <gibber/gibber-namespaces.h>
-#include <gibber/gibber-xmpp-error.h>
 
 #include <salut/caps-channel-manager.h>
 
@@ -164,14 +167,14 @@ salut_muc_manager_close_all (SalutMucManager *self)
     {
       GHashTable *tmp = priv->text_channels;
       priv->text_channels = NULL;
-      g_hash_table_destroy (tmp);
+      g_hash_table_unref (tmp);
     }
 
   if (priv->tubes_channels != NULL)
     {
       GHashTable *tmp = priv->tubes_channels;
       priv->tubes_channels = NULL;
-      g_hash_table_destroy (tmp);
+      g_hash_table_unref (tmp);
     }
 }
 
@@ -209,7 +212,7 @@ salut_muc_manager_constructor (GType type,
       WOCKY_PORTER_HANDLER_PRIORITY_NORMAL + 1, /* so we get called before the IM manager */
       invite_stanza_callback, obj,
       '(', "invite",
-        ':', GIBBER_TELEPATHY_NS_CLIQUE,
+        ':', WOCKY_TELEPATHY_NS_CLIQUE,
       ')', NULL);
 
   priv->status_changed_id = g_signal_connect (priv->connection,
@@ -384,7 +387,7 @@ salut_muc_manager_type_foreach_channel_class (GType type,
   func (type, table, salut_tube_dbus_channel_get_allowed_properties (),
       user_data);
 
-  g_hash_table_destroy (table);
+  g_hash_table_unref (table);
 }
 
 
@@ -492,6 +495,8 @@ salut_muc_manager_new_muc_channel (SalutMucManager *mgr,
       new_connection, requested);
   g_free (path);
 
+  tp_base_channel_register ((TpBaseChannel *) chan);
+
   g_signal_connect (chan, "closed", G_CALLBACK (muc_channel_closed_cb), mgr);
 
   g_hash_table_insert (priv->text_channels, GUINT_TO_POINTER (handle), chan);
@@ -593,7 +598,7 @@ salut_muc_manager_request_new_muc_channel (SalutMucManager *mgr,
   connection = _get_connection (mgr, NULL, params, &connection_error);
 
   if (params != NULL)
-    g_hash_table_destroy (params);
+    g_hash_table_unref (params);
 
   if (connection == NULL)
     {
@@ -697,7 +702,7 @@ create_tubes_channel (SalutMucManager *self,
       g_hash_table_insert (channels, tubes_chan, tokens);
       tp_channel_manager_emit_new_channels (self, channels);
 
-      g_hash_table_destroy (channels);
+      g_hash_table_unref (channels);
       g_slist_free (tokens);
     }
 
@@ -762,7 +767,7 @@ handle_tube_channel_request (SalutMucManager *self,
   g_hash_table_insert (channels, new_channel, request_tokens);
   tp_channel_manager_emit_new_channels (self, channels);
 
-  g_hash_table_destroy (channels);
+  g_hash_table_unref (channels);
   g_slist_free (request_tokens);
   return TRUE;
 }
@@ -1026,7 +1031,7 @@ invite_stanza_callback (WockyPorter *porter,
   SalutContact *contact = SALUT_CONTACT (wocky_stanza_get_from_contact (stanza));
 
   invite = wocky_node_get_child_ns (wocky_stanza_get_top_node (stanza),
-        "invite", GIBBER_TELEPATHY_NS_CLIQUE);
+        "invite", WOCKY_TELEPATHY_NS_CLIQUE);
   g_assert (invite != NULL);
 
   DEBUG("Got an invitation");
@@ -1047,7 +1052,7 @@ invite_stanza_callback (WockyPorter *porter,
     reason = "";
 
   params = gibber_muc_connection_get_required_parameters (
-      GIBBER_TELEPATHY_NS_CLIQUE);
+      WOCKY_TELEPATHY_NS_CLIQUE);
   if (params == NULL)
     {
       DEBUG ("Invalid invitation, (unknown protocol) discarding");
@@ -1084,7 +1089,7 @@ invite_stanza_callback (WockyPorter *porter,
 
   if (chan == NULL)
     {
-      connection = _get_connection (self, GIBBER_TELEPATHY_NS_CLIQUE,
+      connection = _get_connection (self, WOCKY_TELEPATHY_NS_CLIQUE,
           params_hash, NULL);
       if (connection == NULL)
         {
@@ -1121,7 +1126,7 @@ invite_stanza_callback (WockyPorter *porter,
 
 discard:
   if (params_hash != NULL)
-    g_hash_table_destroy (params_hash);
+    g_hash_table_unref (params_hash);
   return TRUE;
 }
 
@@ -1163,7 +1168,7 @@ salut_muc_manager_handle_si_stream_request (SalutMucManager *self,
       GUINT_TO_POINTER (room_handle));
   if (chan == NULL)
     {
-      GError e = { GIBBER_XMPP_ERROR, XMPP_ERROR_BAD_REQUEST,
+      GError e = { WOCKY_XMPP_ERROR, WOCKY_XMPP_ERROR_BAD_REQUEST,
           "No tubes channel available for this MUC" };
 
       DEBUG ("tubes channel doesn't exist for muc %d", room_handle);
