@@ -25,13 +25,10 @@
 #include <string.h>
 #include <glib.h>
 
-#include <wocky/wocky-namespaces.h>
-#include <wocky/wocky-data-form.h>
+#include <wocky/wocky.h>
 
-#include <gibber/gibber-namespaces.h>
 #include <telepathy-glib/channel-manager.h>
 #include <telepathy-glib/intset.h>
-#include <wocky/wocky-caps-hash.h>
 #include <salut/capabilities.h>
 
 #define DEBUG_FLAG DEBUG_PRESENCE
@@ -257,10 +254,10 @@ salut_presence_cache_dispose (GObject *object)
 
   priv->dispose_has_run = TRUE;
 
-  g_hash_table_destroy (priv->capabilities);
+  g_hash_table_unref (priv->capabilities);
   priv->capabilities = NULL;
 
-  g_hash_table_destroy (priv->disco_pending);
+  g_hash_table_unref (priv->disco_pending);
   priv->disco_pending = NULL;
 
   tp_clear_pointer (&(priv->not_xep_capabilities.caps),
