@@ -6,7 +6,15 @@
 #include <telepathy-glib/debug.h>
 
 #include "connection-manager.h"
+
+#ifdef USE_BACKEND_AVAHI
 #include "avahi-discovery-client.h"
+#elif defined (USE_BACKEND_DUMMY)
+#include "dummy-discovery-client.h"
+#elif defined (USE_BACKEND_BONJOUR)
+#include "bonjour-discovery-client.h"
+#endif
+
 #include "debug.h"
 #include "plugin-loader.h"
 #include "symbol-hacks.h"
@@ -16,19 +24,29 @@ salut_create_connection_manager (void)
 {
   return TP_BASE_CONNECTION_MANAGER (
       g_object_new (SALUT_TYPE_CONNECTION_MANAGER,
-                    "backend-type", SALUT_TYPE_AVAHI_DISCOVERY_CLIENT,
+                    "backend-type",
+#ifdef USE_BACKEND_AVAHI
+                    SALUT_TYPE_AVAHI_DISCOVERY_CLIENT,
+#elif defined (USE_BACKEND_DUMMY)
+                    SALUT_TYPE_DUMMY_DISCOVERY_CLIENT,
+#elif defined (USE_BACKEND_BONJOUR)
+                    SALUT_TYPE_BONJOUR_DISCOVERY_CLIENT,
+#endif
                     NULL));
 }
 
 int
+#ifdef BUILD_AS_ANDROID_SERVICE
+salut_main (int argc, char **argv)
+#else
 main (int argc, char **argv)
+#endif
 {
   GLogLevelFlags fatal_mask;
   gint ret;
   SalutPluginLoader *loader;
 
   g_type_init ();
-  g_thread_init (NULL);
 
   salut_symbol_hacks ();
 
