@@ -22,19 +22,22 @@
 #include <stdlib.h>
 #include <unistd.h>
 #include <string.h>
+
+#ifdef G_OS_UNIX
 #include <sys/types.h>
 #include <sys/socket.h>
 #include <netdb.h>
+#endif
+
 #include <errno.h>
 
 #include "self.h"
 
 #include <gibber/gibber-linklocal-transport.h>
-#include <gibber/gibber-namespaces.h>
 #include <gibber/gibber-muc-connection.h>
+
 #include <telepathy-glib/errors.h>
 #include <telepathy-glib/util.h>
-#include <wocky/wocky-xep-0115-capabilities.h>
 
 #include "capabilities.h"
 #include "contact-manager.h"
@@ -234,7 +237,7 @@ salut_self_set_property (GObject *object,
         if (arr != NULL)
           {
             if (self->olpc_key != NULL)
-              g_array_free (self->olpc_key, TRUE);
+              g_array_unref (self->olpc_key);
 
             self->olpc_key = g_array_sized_new (FALSE, FALSE, sizeof (guint8),
                 arr->len);
@@ -471,7 +474,7 @@ salut_self_dispose (GObject *object)
     }
 
   if (priv->olpc_activities != NULL)
-    g_hash_table_destroy (priv->olpc_activities);
+    g_hash_table_unref (priv->olpc_activities);
 
   if (self->olpc_cur_act_room != 0)
     {
@@ -517,7 +520,7 @@ salut_self_finalize (GObject *object)
   g_free (self->alias);
 #ifdef ENABLE_OLPC
   if (self->olpc_key != NULL)
-    g_array_free (self->olpc_key, TRUE);
+    g_array_unref (self->olpc_key);
   g_free (self->olpc_color);
   g_free (self->olpc_cur_act);
 #endif
@@ -639,12 +642,12 @@ salut_self_set_avatar (SalutSelf *self, guint8 *data,
       return TRUE;
     }
 
-  ret = SALUT_SELF_GET_CLASS (self)->set_avatar (self, data, size, error);
+  ret = SALUT_SELF_GET_CLASS (self)->set_avatar (self, data, size, &err);
 
   if (!ret)
     {
       salut_self_remove_avatar (self);
-      if (error != NULL)
+      if (err != NULL)
         *error = g_error_new_literal (TP_ERRORS, TP_ERROR_NETWORK_ERROR,
             err->message);
       g_error_free (err);
