@@ -23,13 +23,9 @@
 #include <stdlib.h>
 #include <string.h>
 
-#include <gibber/gibber-bytestream-ibb.h>
 #include <gibber/gibber-bytestream-oob.h>
-#include <wocky/wocky-stanza.h>
-#include <wocky/wocky-meta-porter.h>
-#include <wocky/wocky-namespaces.h>
-#include <gibber/gibber-namespaces.h>
-#include <gibber/gibber-xmpp-error.h>
+
+#include <wocky/wocky.h>
 
 #include "im-manager.h"
 #include "muc-manager.h"
@@ -92,7 +88,8 @@ streaminit_parse_request (WockyStanza *stanza,
 
   iq = wocky_stanza_get_top_node (stanza);
 
-  *stream_init_id = wocky_node_get_attribute (iq, "id");
+  if (stream_init_id != NULL)
+    *stream_init_id = wocky_node_get_attribute (iq, "id");
 
   *from = wocky_node_get_attribute (iq, "from");
   if (*from == NULL)
@@ -102,7 +99,7 @@ streaminit_parse_request (WockyStanza *stanza,
     }
 
   /* Parse <si> */
-  si = wocky_node_get_child_ns (iq, "si", GIBBER_XMPP_NS_SI);
+  si = wocky_node_get_child_ns (iq, "si", WOCKY_XMPP_NS_SI);
   if (si == NULL)
     return FALSE;
 
@@ -126,14 +123,14 @@ streaminit_parse_request (WockyStanza *stanza,
 
   /* Parse <feature> */
   feature = wocky_node_get_child_ns (si, "feature",
-      GIBBER_XMPP_NS_FEATURENEG);
+      WOCKY_XMPP_NS_FEATURENEG);
   if (feature == NULL)
     {
       DEBUG ("got a SI request without a feature field");
       return FALSE;
     }
 
-  x = wocky_node_get_child_ns (feature, "x", GIBBER_XMPP_NS_DATA);
+  x = wocky_node_get_child_ns (feature, "x", WOCKY_XMPP_NS_DATA);
   if (x == NULL)
     {
       DEBUG ("got a SI request without a X data field");
@@ -222,7 +219,7 @@ choose_bytestream_method (SalutSiBytestreamManager *self,
                           WockyPorter *porter,
                           SalutContact *contact,
                           const gchar *stream_id,
-                          const gchar *stream_init_id)
+                          WockyStanza *stream_init_iq)
 {
   SalutSiBytestreamManagerPrivate *priv =
     SALUT_SI_BYTESTREAM_MANAGER_GET_PRIVATE (self);
@@ -234,7 +231,7 @@ choose_bytestream_method (SalutSiBytestreamManager *self,
   /* check OOB */
   for (l = stream_methods; l != NULL; l = l->next)
     {
-      if (!tp_strdiff (l->data, GIBBER_XMPP_NS_IQ_OOB))
+      if (!tp_strdiff (l->data, WOCKY_XMPP_NS_IQ_OOB))
         {
           DEBUG ("choose OOB in methods list");
           return g_object_new (GIBBER_TYPE_BYTESTREAM_OOB,
@@ -244,25 +241,7 @@ choose_bytestream_method (SalutSiBytestreamManager *self,
               "self-id", priv->connection->name,
               "peer-id", contact->name,
               "contact", contact,
-              "stream-init-id", stream_init_id,
-              NULL);
-        }
-    }
-
-  /* check IBB */
-  for (l = stream_methods; l != NULL; l = l->next)
-    {
-      if (!tp_strdiff (l->data, GIBBER_XMPP_NS_IBB))
-        {
-          DEBUG ("choose IBB in methods list");
-          return g_object_new (GIBBER_TYPE_BYTESTREAM_IBB,
-              "porter", porter,
-              "stream-id", stream_id,
-              "state", GIBBER_BYTESTREAM_STATE_LOCAL_PENDING,
-              "self-id", priv->connection->name,
-              "peer-id", contact->name,
-              "contact", contact,
-              "stream-init-id", stream_init_id,
+              "stream-init-iq", stream_init_iq,
               NULL);
         }
     }
@@ -286,7 +265,7 @@ si_request_cb (WockyPorter *porter,
   GibberBytestreamIface *bytestream = NULL;
   WockyNode *top_node = wocky_stanza_get_top_node (stanza);
   WockyNode *si, *node;
-  const gchar *profile, *from, *stream_id, *stream_init_id, *mime_type;
+  const gchar *profile, *from, *stream_id, *mime_type;
   GSList *stream_methods = NULL;
   WockyContact *contact = wocky_stanza_get_from_contact (stanza);
 
@@ -294,7 +273,7 @@ si_request_cb (WockyPorter *porter,
    * it or send an error reply */
 
   if (!streaminit_parse_request (stanza, &profile, &from, &stream_id,
-        &stream_init_id, &mime_type, &stream_methods))
+        NULL, &mime_type, &stream_methods))
     {
       GError err = { WOCKY_XMPP_ERROR, WOCKY_XMPP_ERROR_BAD_REQUEST,
                       "failed to parse SI request" };
@@ -309,7 +288,7 @@ si_request_cb (WockyPorter *porter,
       return TRUE;
     }
 
-  si = wocky_node_get_child_ns (top_node, "si", GIBBER_XMPP_NS_SI);
+  si = wocky_node_get_child_ns (top_node, "si", WOCKY_XMPP_NS_SI);
   g_assert (si != NULL);
 
   DEBUG ("received a SI request");
@@ -322,7 +301,7 @@ si_request_cb (WockyPorter *porter,
 
   /* check stream method */
   bytestream = choose_bytestream_method (self, stream_methods, porter,
-      SALUT_CONTACT (contact), stream_id, stream_init_id);
+      SALUT_CONTACT (contact), stream_id, stanza);
 
   if (bytestream == NULL)
     {
@@ -353,9 +332,9 @@ si_request_cb (WockyPorter *porter,
      G_CALLBACK (bytestream_state_changed), contact);
 
   /* We inform the right manager we received a SI request */
-  if (tp_strdiff (profile, GIBBER_TELEPATHY_NS_TUBES))
+  if (tp_strdiff (profile, WOCKY_TELEPATHY_NS_TUBES))
     {
-      GError e = { GIBBER_XMPP_ERROR, XMPP_ERROR_SI_BAD_PROFILE, "" };
+      GError e = { WOCKY_SI_ERROR, WOCKY_SI_ERROR_BAD_PROFILE, "" };
       DEBUG ("SI profile unsupported: %s", profile);
 
       gibber_bytestream_iface_close (bytestream, &e);
@@ -367,7 +346,7 @@ si_request_cb (WockyPorter *porter,
    */
 
   if ((node = wocky_node_get_child_ns (si, "muc-stream",
-          GIBBER_TELEPATHY_NS_TUBES)))
+          WOCKY_TELEPATHY_NS_TUBES)))
     {
       const gchar *muc;
       TpHandle room_handle;
@@ -398,7 +377,7 @@ si_request_cb (WockyPorter *porter,
     }
   else
     {
-      GError e = { GIBBER_XMPP_ERROR, XMPP_ERROR_BAD_REQUEST,
+      GError e = { WOCKY_XMPP_ERROR, WOCKY_XMPP_ERROR_BAD_REQUEST,
           "Invalid tube SI request: expected <tube>, <stream> or "
           "<muc-stream>" };
 
@@ -623,13 +602,7 @@ salut_si_bytestream_manager_make_stream_init_iq (const gchar *from,
 
               '(', "option",
                 '(', "value",
-                  '$', GIBBER_XMPP_NS_IQ_OOB,
-                ')',
-              ')',
-
-              '(', "option",
-                '(', "value",
-                  '$', GIBBER_XMPP_NS_IBB,
+                  '$', WOCKY_XMPP_NS_IQ_OOB,
                 ')',
               ')',
 
@@ -756,7 +729,7 @@ si_request_sent_cb (GObject *source_object,
     }
 
   si = wocky_node_get_child_ns (node, "si",
-      GIBBER_XMPP_NS_SI);
+      WOCKY_XMPP_NS_SI);
   if (si == NULL)
     {
       DEBUG ("got a SI reply without a si field");
@@ -764,14 +737,14 @@ si_request_sent_cb (GObject *source_object,
     }
 
   feature = wocky_node_get_child_ns (si, "feature",
-      GIBBER_XMPP_NS_FEATURENEG);
+      WOCKY_XMPP_NS_FEATURENEG);
   if (feature == NULL)
     {
       DEBUG ("got a SI reply without a feature field");
       goto END;
     }
 
-  x = wocky_node_get_child_ns (feature, "x", GIBBER_XMPP_NS_DATA);
+  x = wocky_node_get_child_ns (feature, "x", WOCKY_XMPP_NS_DATA);
   if (x == NULL)
     {
       DEBUG ("got a SI reply without a x field");
@@ -798,7 +771,7 @@ si_request_sent_cb (GObject *source_object,
 
       stream_method = value->content;
 
-      if (!tp_strdiff (stream_method, GIBBER_XMPP_NS_IQ_OOB))
+      if (!tp_strdiff (stream_method, WOCKY_XMPP_NS_IQ_OOB))
       {
         /* Remote user have accepted the stream */
         DEBUG ("remote user chose a OOB bytestream");
@@ -809,27 +782,13 @@ si_request_sent_cb (GObject *source_object,
               "self-id", priv->connection->name,
               "peer-id", from,
               "contact", wocky_stanza_get_from_contact (stanza),
-              "stream-init-id", NULL,
+              "stream-init-iq", NULL,
               "host", priv->host_name_fqdn,
               NULL);
         gibber_bytestream_oob_set_check_addr_func (
             GIBBER_BYTESTREAM_OOB (bytestream), check_bytestream_oob_peer_addr,
             data->self);
       }
-    else if (!tp_strdiff (stream_method, GIBBER_XMPP_NS_IBB))
-      {
-        /* Remote user have accepted the stream */
-        DEBUG ("remote user chose a IBB bytestream");
-        bytestream = g_object_new (GIBBER_TYPE_BYTESTREAM_IBB,
-              "porter", porter,
-              "stream-id", data->stream_id,
-              "state", GIBBER_BYTESTREAM_STATE_INITIATING,
-              "self-id", priv->connection->name,
-              "peer-id", from,
-              "contact", wocky_stanza_get_from_contact (stanza),
-              "stream-init-id", NULL,
-              NULL);
-      }
     else
       {
         DEBUG ("Remote user chose an unsupported stream method");
