@@ -22,6 +22,15 @@
 #include <stdlib.h>
 #include <string.h>
 #include <time.h>
+
+#include <glib.h>
+
+#ifdef G_OS_WIN32
+#include <winsock2.h>
+#include <ws2tcpip.h>
+#include <windows.h>
+#include <winbase.h>
+#else
 #include <sys/types.h>
 #include <sys/socket.h>
 #include <sys/un.h>
@@ -29,8 +38,8 @@
 #include <fcntl.h>
 #include <errno.h>
 #include <netdb.h>
+#endif
 
-#include <glib.h>
 #include <glib/gstdio.h>
 #include <telepathy-glib/gtypes.h>
 
@@ -42,10 +51,7 @@
 #include <telepathy-glib/svc-channel.h>
 #include <telepathy-glib/svc-generic.h>
 
-#include <wocky/wocky-stanza.h>
-#include <wocky/wocky-namespaces.h>
-#include <wocky/wocky-namespaces.h>
-#include <wocky/wocky-stanza.h>
+#include <wocky/wocky.h>
 
 #include <gibber/gibber-bytestream-direct.h>
 #include <gibber/gibber-bytestream-iface.h>
@@ -102,8 +108,10 @@ static const gchar * const salut_tube_stream_channel_allowed_properties[] = {
  * not guaranteed to be big enough for AF_UNIX addresses */
 typedef union
 {
+#ifdef GIBBER_TYPE_UNIX_TRANSPORT
   /* we'd call this unix, but gcc predefines that. Thanks, gcc */
   struct sockaddr_un un;
+#endif
   struct sockaddr_in ipv4;
   struct sockaddr_in6 ipv6;
 } SockAddr;
@@ -770,6 +778,7 @@ new_connection_to_socket (SalutTubeStream *self,
 
   g_assert (priv->initiator == priv->self_handle);
 
+#ifdef GIBBER_TYPE_UNIX_TRANSPORT
   if (priv->address_type == TP_SOCKET_ADDRESS_TYPE_UNIX)
     {
       GArray *array;
@@ -780,7 +789,9 @@ new_connection_to_socket (SalutTubeStream *self,
       gibber_unix_transport_connect (GIBBER_UNIX_TRANSPORT (transport),
           array->data, NULL);
     }
-  else if (priv->address_type == TP_SOCKET_ADDRESS_TYPE_IPV4 ||
+  else
+#endif
+  if (priv->address_type == TP_SOCKET_ADDRESS_TYPE_IPV4 ||
       priv->address_type == TP_SOCKET_ADDRESS_TYPE_IPV6)
     {
       gchar *ip;
@@ -861,7 +872,7 @@ tube_stream_open (SalutTubeStream *self,
       priv->address = tp_g_value_slice_new (DBUS_TYPE_G_UCHAR_ARRAY);
       g_value_set_boxed (priv->address, array);
 
-      g_array_free (array, TRUE);
+      g_array_unref (array);
 
       ret = gibber_listener_listen_socket (priv->local_listener, path, FALSE,
           error);
@@ -1028,19 +1039,19 @@ salut_tube_stream_dispose (GObject *object)
 
   if (priv->transport_to_bytestream != NULL)
     {
-      g_hash_table_destroy (priv->transport_to_bytestream);
+      g_hash_table_unref (priv->transport_to_bytestream);
       priv->transport_to_bytestream = NULL;
     }
 
   if (priv->bytestream_to_transport != NULL)
     {
-      g_hash_table_destroy (priv->bytestream_to_transport);
+      g_hash_table_unref (priv->bytestream_to_transport);
       priv->bytestream_to_transport = NULL;
     }
 
   if (priv->transport_to_id != NULL)
     {
-      g_hash_table_destroy (priv->transport_to_id);
+      g_hash_table_unref (priv->transport_to_id);
       priv->transport_to_id = NULL;
     }
 
@@ -1074,7 +1085,7 @@ salut_tube_stream_finalize (GObject *object)
   g_free (priv->service);
   if (priv->parameters != NULL)
     {
-      g_hash_table_destroy (priv->parameters);
+      g_hash_table_unref (priv->parameters);
       priv->parameters = NULL;
     }
 
@@ -1299,7 +1310,7 @@ salut_tube_stream_set_property (GObject *object,
         break;
       case PROP_PARAMETERS:
         if (priv->parameters != NULL)
-          g_hash_table_destroy (priv->parameters);
+          g_hash_table_unref (priv->parameters);
         priv->parameters = g_value_dup_boxed (value);
         break;
       case PROP_OFFERED:
@@ -2013,6 +2024,7 @@ salut_tube_stream_add_bytestream (SalutTubeIface *tube,
     }
 }
 
+#ifdef GIBBER_TYPE_UNIX_TRANSPORT
 static gboolean
 check_unix_params (TpSocketAddressType address_type,
                    const GValue *address,
@@ -2090,6 +2102,7 @@ check_unix_params (TpSocketAddressType address_type,
 
   return TRUE;
 }
+#endif
 
 static gboolean
 check_ip_params (TpSocketAddressType address_type,
@@ -2174,10 +2187,11 @@ salut_tube_stream_check_params (TpSocketAddressType address_type,
 {
   switch (address_type)
     {
+#ifdef GIBBER_TYPE_UNIX_TRANSPORT
       case TP_SOCKET_ADDRESS_TYPE_UNIX:
         return check_unix_params (address_type, address, access_control,
             access_control_param, error);
-
+#endif
       case TP_SOCKET_ADDRESS_TYPE_IPV4:
       case TP_SOCKET_ADDRESS_TYPE_IPV6:
         return check_ip_params (address_type, address, access_control,
@@ -2392,7 +2406,7 @@ static void
 destroy_socket_control_list (gpointer data)
 {
   GArray *tab = data;
-  g_array_free (tab, TRUE);
+  g_array_unref (tab);
 }
 
 GHashTable *
