@@ -19,7 +19,6 @@
  */
 
 #include "util.h"
-#include <salut/util.h>
 
 #include <stdlib.h>
 #include <string.h>
@@ -322,70 +321,3 @@ salut_generate_id (void)
       last++, g_random_int ());
 #endif
 }
-
-static void
-send_stanza_to_contact (WockyPorter *porter,
-    WockyContact *contact,
-    WockyStanza *stanza)
-{
-  WockyStanza *to_send = wocky_stanza_copy (stanza);
-
-  wocky_stanza_set_to_contact (to_send, contact);
-  wocky_porter_send (porter, to_send);
-  g_object_unref (to_send);
-}
-
-void
-salut_send_ll_pep_event (WockySession *session,
-    WockyStanza *stanza)
-{
-  WockyContactFactory *contact_factory;
-  WockyPorter *porter;
-  WockyLLContact *self_contact;
-  GList *contacts, *l;
-  WockyNode *message, *event, *items;
-  const gchar *pep_node;
-  gchar *node;
-
-  g_return_if_fail (WOCKY_IS_SESSION (session));
-  g_return_if_fail (WOCKY_IS_STANZA (stanza));
-
-  message = wocky_stanza_get_top_node (stanza);
-  event = wocky_node_get_first_child (message);
-  items = wocky_node_get_first_child (event);
-
-  pep_node = wocky_node_get_attribute (items, "node");
-
-  if (pep_node == NULL)
-    return;
-
-  node = g_strdup_printf ("%s+notify", pep_node);
-
-  contact_factory = wocky_session_get_contact_factory (session);
-  porter = wocky_session_get_porter (session);
-
-  contacts = wocky_contact_factory_get_ll_contacts (contact_factory);
-
-  for (l = contacts; l != NULL; l = l->next)
-    {
-      SalutContact *contact;
-
-      if (!SALUT_IS_CONTACT (l->data))
-        continue;
-
-      contact = l->data;
-
-      if (gabble_capability_set_has (contact->caps, node))
-        send_stanza_to_contact (porter, WOCKY_CONTACT (contact), stanza);
-    }
-
-  /* now send to self */
-  self_contact = wocky_contact_factory_ensure_ll_contact (contact_factory,
-      wocky_porter_get_full_jid (porter));
-
-  send_stanza_to_contact (porter, WOCKY_CONTACT (self_contact), stanza);
-
-  g_object_unref (self_contact);
-  g_list_free (contacts);
-  g_free (node);
-}
